@@ -8,7 +8,7 @@ use Alien::Build::Util qw( _ssl_reqs );
 use Carp ();
 
 # ABSTRACT: Plugin for fetching files using HTTP::Tiny
-our $VERSION = '1.69'; # VERSION
+our $VERSION = '1.74'; # VERSION
 
 
 has '+url' => '';
@@ -127,7 +127,7 @@ Alien::Build::Plugin::Fetch::HTTPTiny - Plugin for fetching files using HTTP::Ti
 
 =head1 VERSION
 
-version 1.69
+version 1.74
 
 =head1 SYNOPSIS
 
@@ -172,7 +172,7 @@ Contributors:
 
 Diab Jerius (DJERIUS)
 
-Roy Storey
+Roy Storey (KIWIROY)
 
 Ilya Pavlov
 
